ELECTRUM_VERSION = "1.9.7"  # version of the client package
PROTOCOL_VERSION = '0.6'    # protocol version requested
SEED_VERSION     = 4        # bump this every time the seed generation is modified
SEED_PREFIX      = '01'     # the hash of the mnemonic seed must begin with this

